@@ -42,11 +42,8 @@ macro_rules! deref {
 
 macro_rules! raise(
     ($message:expr) => (return Err(::Error::new(::std::io::ErrorKind::Other, $message)));
-    ($($argument:tt)+) => (raise!(format!($($argument)+)));
 );
 
-#[doc(hidden)]
-#[macro_export]
 macro_rules! table {
     ($(#[$attribute:meta])* pub $structure:ident {
         $($field:ident ($kind:ty),)*
